@@ -877,12 +877,14 @@ gint read_config(AppletConfig * config) {
                 || config->mode > EXPANDED_VIEW_MODE)
                         config->view_mode = COLLAPSED_VIEW_MODE;
 
-    /* Get mod Drfault Digia*/
+    /* Get mod Default Digia*/
     tmp = NULL;
     tmp = gconf_client_get_string(gconf_client,
                                               GCONF_KEY_MOD,
                                               &gerror);
+    fprintf(stderr,"qqqqqqqqqqqqqqqqqqqqqqqq %s\n", tmp);
     if (!tmp ||gerror) {
+        fprintf(stderr, "sssssssssssssssssssssssss \n");
         config->mod = g_strdup("Digia");
         if(gerror){
             g_error_free(gerror);
