@@ -12,16 +12,16 @@
  *	for default icon set (Glance)
  *
  * This software is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public License
+ * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2.1 of
  * the License, or (at your option) any later version.
  *
  * This software is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Lesser General Public License for more details.
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
+ * You should have received a copy of the GNU weather-config.h General Public
  * License along with this software; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
  * 02110-1301 USA
@@ -94,6 +94,7 @@
 #define GCONF_KEY_VIEW_MODE                         GCONF_KEY_PREFIX"/view_mode"
 #define GCONF_KEY_ENABLE_ANIMATION                  GCONF_KEY_PREFIX"/animation"
 #define GCONF_KEY_SCALE_IN_POPUP                    GCONF_KEY_PREFIX"/scale_in_popup"
+#define GCONF_KEY_MOD                               GCONF_KEY_PREFIX"/mod"
 /*******************************************************************************/
 gboolean config_set_weather_dir_name(gchar *new_weather_dir_name);
 void config_update_proxy(void);
